==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/statemachine/impl/InstanceStateMachineSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.statemachine.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.statemachine.InstanceStateMachine;
import io.ciera.tool.sql.ooaofooa.statemachine.InstanceStateMachineSet;
import io.ciera.tool.sql.ooaofooa.statemachine.SM_SMSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.SM_SMSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.ModelClassSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.ModelClassSetImpl;

import java.util.Arrays;
import java.util.List;


public class InstanceStateMachineSetImpl extends InstanceSet<InstanceStateMachineSet,InstanceStateMachine> implements InstanceStateMachineSet {

    // attributes
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( InstanceStateMachine instancestatemachine : this ) instancestatemachine.setObj_ID( ref_Obj_ID );
    }
    @Override
    public void setSM_ID( UniqueId ref_SM_ID ) throws XtumlException {
        for ( InstanceStateMachine instancestatemachine : this ) instancestatemachine.setSM_ID( ref_SM_ID );
    }


    // selections
    @Override
    public SM_SMSet R517_is_a_SM_SM() throws XtumlException {
        SM_SMSet sm_smset = new SM_SMSetImpl();
        for ( InstanceStateMachine instancestatemachine : this ) sm_smset.add( instancestatemachine.R517_is_a_SM_SM() );
        return sm_smset;
    }
    @Override
    public ModelClassSet R518_ModelClass() throws XtumlException {
        ModelClassSet modelclassset = new ModelClassSetImpl();
        for ( InstanceStateMachine instancestatemachine : this ) modelclassset.add( instancestatemachine.R518_ModelClass() );
        return modelclassset;
    }


    @Override
    public InstanceStateMachine nullElement() {
        return InstanceStateMachineImpl.EMPTY_INSTANCESTATEMACHINE;
    }

    @Override
    public InstanceStateMachineSet emptySet() {
      return new InstanceStateMachineSetImpl();
    }

    @Override
    public InstanceStateMachineSet value() {
        return this;
    }

    @Override
    public List<InstanceStateMachine> elements() {
        return Arrays.asList(toArray(new InstanceStateMachine[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/statemachine/impl/InstanceStateMachineSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.statemachine.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.statemachine.InstanceStateMachine;
import io.ciera.tool.sql.ooaofooa.statemachine.InstanceStateMachineSet;
import io.ciera.tool.sql.ooaofooa.statemachine.SM_SMSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.SM_SMSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.ModelClassSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.ModelClassSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class InstanceStateMachineSetImpl extends InstanceSet<InstanceStateMachineSet,InstanceStateMachine> implements InstanceStateMachineSet {

    public InstanceStateMachineSetImpl() {
    }

    public InstanceStateMachineSetImpl(Comparator<? super InstanceStateMachine> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setSM_ID( UniqueId ref_SM_ID ) throws XtumlException {
        for ( InstanceStateMachine instancestatemachine : this ) instancestatemachine.setSM_ID( ref_SM_ID );
    }
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( InstanceStateMachine instancestatemachine : this ) instancestatemachine.setObj_ID( ref_Obj_ID );
    }


    // selections
    @Override
    public SM_SMSet R517_is_a_SM_SM() throws XtumlException {
        SM_SMSet sm_smset = new SM_SMSetImpl();
        for ( InstanceStateMachine instancestatemachine : this ) sm_smset.add( instancestatemachine.R517_is_a_SM_SM() );
        return sm_smset;
    }
    @Override
    public ModelClassSet R518_ModelClass() throws XtumlException {
        ModelClassSet modelclassset = new ModelClassSetImpl();
        for ( InstanceStateMachine instancestatemachine : this ) modelclassset.add( instancestatemachine.R518_ModelClass() );
        return modelclassset;
    }


    @Override
    public InstanceStateMachine nullElement() {
        return InstanceStateMachineImpl.EMPTY_INSTANCESTATEMACHINE;
    }

    @Override
    public InstanceStateMachineSet emptySet() {
      return new InstanceStateMachineSetImpl();
    }

    @Override
    public InstanceStateMachineSet emptySet(Comparator<? super InstanceStateMachine> comp) {
      return new InstanceStateMachineSetImpl(comp);
    }

    @Override
    public InstanceStateMachineSet value() {
        return this;
    }

    @Override
    public List<InstanceStateMachine> elements() {
        return Arrays.asList(toArray(new InstanceStateMachine[0]));
    }

}
